
#include <qwidget.h>
#include <malloc.h>
#include "fileedit.h"

FileEdit::FileEdit( QWidget* parent, const char* name)
    : QTextEdit( parent, name )
{
    filetext = NULL;
    pathtext = NULL;
    tabnum = 0;
    nextItem = NULL;
    init();
}

void FileEdit::init()
{
    setPaletteBackgroundColor ( QColor(128, 128, 128) );
    verticalScrollBar()->setPaletteBackgroundColor ( QColor(128, 128, 128) );
    verticalScrollBar()->setPaletteForegroundColor ( QColor(128, 128, 128) );
    connect(this, SIGNAL( selectionChanged() ), this, SLOT( handleSelected() ));
}

void FileEdit::close()
{
    emit( closed(this) );
}

void FileEdit::set(const char *filename, const char *path, int tab)
{
    filetext = new QString(filename);
    pathtext = new QString(path);
    tabnum = tab;
}

bool FileEdit::equals(const char *filepath)
{
    return (*pathtext == filepath);
}

void FileEdit::setNext(FileEdit *configFile)
{
    nextItem = configFile;
}

FileEdit* FileEdit::getNext()
{
    return nextItem;
}

int FileEdit::getTab()
{
    return tabnum;
}

void FileEdit::setTab(int num)
{
    tabnum = num;
}

QString FileEdit::getFileName()
{
    return *filetext;
}

QString FileEdit::getPath()
{
    return *pathtext;
}   

void FileEdit::handleSelected()
{
    if (hasSelectedText())
    {
	emit(selected(selectedText()));
    }
}

bool FileEdit::findString( QString searchString, bool direction, bool optionCS, bool optionWO )
{
    int para=0, index=0, strlen=searchString.length();
    int paraFrom, indexFrom, paraTo, indexTo;
    bool found;
    
    // if there is a selection, begin search at the end of it
    if ( hasSelectedText() )
    {
	getSelection(&paraFrom, &indexFrom, &paraTo, &indexTo);	
	if (direction)
	{
	    para  = paraTo;
	    index = indexTo;
	}
	else
	{
	    para  = paraFrom;
	    index = indexFrom;
	}
    }
    else
    {
	getCursorPosition(&para, &index);
    }
    
    // Search and set selection, if not found then start search at the beginning
    found = find(searchString,optionCS, optionWO, direction, &para, &index);
    if (found)
    {
	if (direction)
	    { setSelection(para, index, para, index+strlen); }
	else
	    { setSelection(para, index-strlen, para, index); }
	setCursorPosition(para, index+strlen);
    }
    else
    {
	// Begin search at the beginning / end 
	if (direction)
	{ para = 0; index = 0; }
	else
	{ para = lines(); index = paragraphLength(para);}
	
	found = find(searchString,optionCS, optionWO, direction, &para, &index);
	if (found)
	{
	    setCursorPosition(para, index+strlen);
	}
	else
	{ 
	    removeSelection();
	    return false;
	}
   }
    return true;
}

FileEdit::~FileEdit()
{
    disconnect(this, SIGNAL( selectionChanged() ), this, SLOT( handleSelected() ));
    // no need to delete child widgets, Qt does it all for us
}
